The python part of cheminformatics-EDU, use: !pip install gressling

Example notebook here:  [gressling.ipynb](https://colab.research.google.com/drive/1KDKH9iVO2niYitIt1kFzE4RHw3O6ppaR#scrollTo=B7hP9SoJ2fRh)
